@@ -1,4 +1,4 @@
-from typing import cast
+from typing import TYPE_CHECKING, Optional, Sequence, Tuple, cast
 
 from graphene import ResolveInfo
 
@@ -6,16 +6,19 @@ import dagster._check as check
 from dagster._core.errors import DagsterRunNotFoundError
 from dagster._core.execution.plan.resume_retry import get_retry_steps_from_parent_run
 from dagster._core.execution.plan.state import KnownExecutionState
+from dagster._core.host_representation.external import ExternalPipeline
 from dagster._core.instance import DagsterInstance
-from dagster._core.storage.pipeline_run import DagsterRun, PipelineRunStatus
+from dagster._core.storage.pipeline_run import DagsterRun, DagsterRunStatus
 from dagster._core.storage.tags import RESUME_RETRY_TAG
 from dagster._core.utils import make_new_run_id
 from dagster._utils import merge_dicts
 
-from ...schema.errors import GrapheneNoModeProvidedError
 from ..external import ensure_valid_config, get_external_execution_plan_or_raise
 from ..utils import ExecutionParams, UserFacingGraphQLError
 
+if TYPE_CHECKING:
+    from dagster_graphql.schema.util import HasContext
+
 
 def _get_run(instance: DagsterInstance, run_id: str) -> DagsterRun:
     run = instance.get_run_by_id(run_id)
@@ -24,15 +27,18 @@ def _get_run(instance: DagsterInstance, run_id: str) -> DagsterRun:
     return cast(DagsterRun, run)
 
 
-def compute_step_keys_to_execute(graphene_info, execution_params):
+def compute_step_keys_to_execute(
+    graphene_info: "HasContext", execution_params: ExecutionParams
+) -> Tuple[Optional[Sequence[str]], Optional[KnownExecutionState]]:
     check.inst_param(graphene_info, "graphene_info", ResolveInfo)
     check.inst_param(execution_params, "execution_params", ExecutionParams)
 
-    instance: DagsterInstance = graphene_info.context.instance
+    instance = graphene_info.context.instance
 
     if not execution_params.step_keys and is_resume_retry(execution_params):
         # Get step keys from parent_run_id if it's a resume/retry
-        parent_run = _get_run(instance, execution_params.execution_metadata.parent_run_id)
+        parent_run_id = check.not_none(execution_params.execution_metadata.parent_run_id)
+        parent_run = _get_run(instance, parent_run_id)
         return get_retry_steps_from_parent_run(
             instance,
             parent_run,
@@ -54,7 +60,14 @@ def is_resume_retry(execution_params):
     return execution_params.execution_metadata.tags.get(RESUME_RETRY_TAG) == "true"
 
 
-def create_valid_pipeline_run(graphene_info, external_pipeline, execution_params):
+def create_valid_pipeline_run(
+    graphene_info: "HasContext",
+    external_pipeline: ExternalPipeline,
+    execution_params: ExecutionParams,
+):
+    from ...schema.errors import GrapheneNoModeProvidedError
+
+    mode: Optional[str]
     if execution_params.mode is None and len(external_pipeline.available_modes) > 1:
         raise UserFacingGraphQLError(
             GrapheneNoModeProvidedError(external_pipeline.name, external_pipeline.available_modes)
@@ -102,7 +115,7 @@ def create_valid_pipeline_run(graphene_info, external_pipeline, execution_params
         tags=tags,
         root_run_id=execution_params.execution_metadata.root_run_id,
         parent_run_id=execution_params.execution_metadata.parent_run_id,
-        status=PipelineRunStatus.NOT_STARTED,
+        status=DagsterRunStatus.NOT_STARTED,
         external_pipeline_origin=external_pipeline.get_external_origin(),
         pipeline_code_origin=external_pipeline.get_python_origin(),
     )
