@@ -27,6 +27,7 @@ from .utils import capture_error
 if TYPE_CHECKING:
     from ..schema.asset_graph import GrapheneAssetNode
     from ..schema.freshness_policy import GrapheneAssetFreshnessInfo
+    from ..schema.util import HasContext
 
 
 def _normalize_asset_cursor_str(cursor_string):
@@ -85,11 +86,13 @@ def asset_node_iter(
                 yield location, repository, external_asset_node
 
 
-def get_asset_node_definition_collisions(graphene_info, asset_keys):
+def get_asset_node_definition_collisions(
+    graphene_info: "HasContext", asset_keys: Sequence[AssetKey]
+):
     from ..schema.asset_graph import GrapheneAssetNodeDefinitionCollision
     from ..schema.external import GrapheneRepository
 
-    repos: Dict[AssetKey, GrapheneRepository] = defaultdict(list)
+    repos: Dict[AssetKey, List[GrapheneRepository]] = defaultdict(list)
 
     for repo_loc, repo, external_asset_node in asset_node_iter(graphene_info):
         if external_asset_node.asset_key in asset_keys:
@@ -259,7 +262,9 @@ def get_assets_for_run_id(graphene_info, run_id):
 
 
 def get_unique_asset_id(
-    asset_key: AssetKey, repository_location_name: str = None, repository_name: str = None
+    asset_key: AssetKey,
+    repository_location_name: Optional[str] = None,
+    repository_name: Optional[str] = None,
 ) -> str:
     repository_identifier = (
         f"{repository_location_name}.{repository_name}"
@@ -393,22 +398,14 @@ def get_freshness_info(
         asset_graph=asset_graph, record=latest_record
     )
 
-    # in the future, if you have upstream source assets with versioning policies, available data
-    # times will be based off of the timestamp of the most recent materializations.
     current_minutes_late = freshness_policy.minutes_late(
         evaluation_time=current_time,
         used_data_times=used_data_times,
-        available_data_times={
-            # assume materializing an asset at time T will update the data time of that asset to T
-            key: current_time
-            for key in used_data_times.keys()
-        },
     )
 
     latest_materialization_minutes_late = freshness_policy.minutes_late(
         evaluation_time=latest_materialization_time,
         used_data_times=used_data_times,
-        available_data_times={key: latest_materialization_time for key in used_data_times.keys()},
     )
 
     return GrapheneAssetFreshnessInfo(
