@@ -1,8 +1,8 @@
 import graphene
 
 import dagster._check as check
-from dagster._core.execution.backfill import BulkActionStatus, PartitionBackfill
-from dagster._core.storage.pipeline_run import FINISHED_STATUSES, PipelineRunStatus, RunsFilter
+from dagster._core.execution.backfill import PartitionBackfill
+from dagster._core.storage.pipeline_run import RunsFilter
 from dagster._core.storage.tags import BACKFILL_ID_TAG
 
 from ..implementation.fetch_partition_sets import partition_statuses_from_run_partition_data
@@ -86,32 +86,19 @@ class GrapheneBulkActionStatus(graphene.Enum):
         name = "BulkActionStatus"
 
 
-class GrapheneBackfillStatus(graphene.Enum):
-    REQUESTED = "REQUESTED"
-    FAILED = "FAILED"
-    CANCELED = "CANCELED"
-    IN_PROGRESS = "IN_PROGRESS"
-    COMPLETED = "COMPLETED"
-    INCOMPLETE = "INCOMPLETE"
-
-    class Meta:
-        name = "BackfillStatus"
-
-
 class GraphenePartitionBackfill(graphene.ObjectType):
     class Meta:
         name = "PartitionBackfill"
 
     backfillId = graphene.NonNull(graphene.String)
     status = graphene.NonNull(GrapheneBulkActionStatus)
-    backfillStatus = graphene.NonNull(GrapheneBackfillStatus)
     partitionNames = non_null_list(graphene.String)
     numPartitions = graphene.NonNull(graphene.Int)
-    numRequested = graphene.NonNull(graphene.Int)
+    numCancelable = graphene.NonNull(graphene.Int)
     fromFailure = graphene.NonNull(graphene.Boolean)
-    reexecutionSteps = non_null_list(graphene.String)
+    reexecutionSteps = graphene.List(graphene.NonNull(graphene.String))
     assetSelection = graphene.List(graphene.NonNull(GrapheneAssetKey))
-    partitionSetName = graphene.NonNull(graphene.String)
+    partitionSetName = graphene.Field(graphene.String)
     timestamp = graphene.NonNull(graphene.Float)
     partitionSet = graphene.Field("dagster_graphql.schema.partition_sets.GraphenePartitionSet")
     runs = graphene.Field(
@@ -135,16 +122,18 @@ class GraphenePartitionBackfill(graphene.ObjectType):
 
         super().__init__(
             backfillId=backfill_job.backfill_id,
-            partitionSetName=backfill_job.partition_set_origin.partition_set_name,
+            partitionSetName=backfill_job.partition_set_name,
             status=backfill_job.status.value,
             fromFailure=bool(backfill_job.from_failure),
             reexecutionSteps=backfill_job.reexecution_steps,
-            partitionNames=backfill_job.partition_names,
             timestamp=backfill_job.backfill_timestamp,
             assetSelection=backfill_job.asset_selection,
         )
 
     def _get_partition_set(self, graphene_info):
+        if self._backfill_job.partition_set_origin is None:
+            return None
+
         origin = self._backfill_job.partition_set_origin
         location_name = origin.external_repository_origin.repository_location_origin.location_name
         repository_name = origin.external_repository_origin.repository_name
@@ -193,53 +182,20 @@ class GraphenePartitionBackfill(graphene.ObjectType):
         records = self._get_records(graphene_info)
         return [GrapheneRun(record) for record in records if not record.pipeline_run.is_finished]
 
-    def resolve_backfillStatus(self, graphene_info):
-        if self._backfill_job.status == BulkActionStatus.REQUESTED:
-            return GrapheneBackfillStatus.REQUESTED
-        if self._backfill_job.status == BulkActionStatus.CANCELED:
-            return GrapheneBackfillStatus.CANCELED
-        if self._backfill_job.status == BulkActionStatus.FAILED:
-            return GrapheneBackfillStatus.FAILED
-        if self._backfill_job.status == BulkActionStatus.COMPLETED:
-            partition_run_data = self._get_partition_run_data(graphene_info)
-            is_done = all(partition.status in FINISHED_STATUSES for partition in partition_run_data)
-            if not is_done:
-                return GrapheneBackfillStatus.IN_PROGRESS
-            else:
-                num_success = len(
-                    [
-                        partition
-                        for partition in partition_run_data
-                        if partition.status == PipelineRunStatus.SUCCESS
-                    ]
-                )
-                if num_success == len(self._backfill_job.partition_names):
-                    return GrapheneBackfillStatus.COMPLETED
-                else:
-                    return GrapheneBackfillStatus.INCOMPLETE
-
     def resolve_runs(self, graphene_info):
         from .pipelines.pipeline import GrapheneRun
 
         records = self._get_records(graphene_info)
         return [GrapheneRun(record) for record in records]
 
+    def resolve_partitionNames(self, _graphene_info):
+        return self._backfill_job.get_partition_names(_graphene_info.context)
+
     def resolve_numPartitions(self, _graphene_info):
-        return len(self._backfill_job.partition_names)
+        return self._backfill_job.get_num_partitions(_graphene_info.context)
 
-    def resolve_numRequested(self, graphene_info):
-        if self._backfill_job.status == BulkActionStatus.COMPLETED:
-            return len(self._backfill_job.partition_names)
-
-        partition_run_data = self._get_partition_run_data(graphene_info)
-
-        checkpoint = self._backfill_job.last_submitted_partition_name
-        return max(
-            len(partition_run_data),
-            self._backfill_job.partition_names.index(checkpoint) + 1
-            if checkpoint and checkpoint in self._backfill_job.partition_names
-            else 0,
-        )
+    def resolve_numCancelable(self, _graphene_info):
+        return self._backfill_job.get_num_cancelable()
 
     def resolve_partitionSet(self, graphene_info):
         from ..schema.partition_sets import GraphenePartitionSet
@@ -255,12 +211,15 @@ class GraphenePartitionBackfill(graphene.ObjectType):
         )
 
     def resolve_partitionStatuses(self, graphene_info):
-        partition_set_name = self._backfill_job.partition_set_origin.partition_set_name
+        partition_set_origin = self._backfill_job.partition_set_origin
+        partition_set_name = (
+            partition_set_origin.partition_set_name if partition_set_origin else None
+        )
         partition_run_data = self._get_partition_run_data(graphene_info)
         return partition_statuses_from_run_partition_data(
             partition_set_name,
             partition_run_data,
-            self._backfill_job.partition_names,
+            self._backfill_job.get_partition_names(graphene_info.context),
             backfill_id=self._backfill_job.backfill_id,
         )
 
