@@ -14,6 +14,15 @@ class GrapheneError(graphene.Interface):
         name = "Error"
 
 
+class GrapheneErrorChainLink(graphene.ObjectType):
+    class Meta:
+        interfaces = (GrapheneError,)
+        name = "ErrorChainLink"
+
+    error = graphene.NonNull(lambda: GraphenePythonError)
+    isExplicitLink = graphene.NonNull(graphene.Boolean)
+
+
 class GraphenePythonError(graphene.ObjectType):
     class Meta:
         interfaces = (GrapheneError,)
@@ -25,7 +34,7 @@ class GraphenePythonError(graphene.ObjectType):
 
     """
     A list of all recursive errors deeper in the exception stack that caused this error to be
-    raised. For example, in a block of code like:
+    raised, only including explicit raises. For example, in a block of code like:
     ```
         try:
             try:
@@ -39,22 +48,92 @@ class GraphenePythonError(graphene.ObjectType):
     """
     causes = non_null_list("dagster_graphql.schema.errors.GraphenePythonError")
 
+    """
+    A list of all recursive errors deeper in the exception stack that caused this error to be
+    raised, including both explicit and implicit links. For example, in a block of code like:
+    ```
+        try:
+            try:
+                raise Exception("Inner")
+            except Exception as e:
+                raise Exception("Middle")
+        except Exception as e:
+            raise Exception("Outer") from e
+    ```
+    The PythonError returned will correspond to Outer, with two links in the chain - one explicit (Middle) then one implicit (Inner)
+    """
+
+    errorChain = non_null_list(GrapheneErrorChainLink)
+
     def __init__(self, error_info):
         super().__init__()
-        check.inst_param(error_info, "error_info", SerializableErrorInfo)
-        self.message = error_info.message
-        self.stack = error_info.stack
-        self.cause = error_info.cause
-        self.className = error_info.cls_name
+        self._error_info = check.inst_param(error_info, "error_info", SerializableErrorInfo)
+        self._message = error_info.message
+        self._stack = error_info.stack
+        self._className = error_info.cls_name
+        self._cause = error_info.cause
+        self._context = error_info.context
+
+    def resolve_message(self, _graphene_info):
+        check.invariant(
+            isinstance(self, GraphenePythonError),
+            f"GraphenePythonError methods called on a {type(self)} - this usually indicates that "
+            "a SerializableErrorInfo was passed in where a GraphenePythonError was expected",
+        )
+        return self._message
+
+    def resolve_stack(self, _graphene_info):
+        check.invariant(
+            isinstance(self, GraphenePythonError),
+            f"GraphenePythonError methods called on a {type(self)} - this usually indicates that "
+            "a SerializableErrorInfo was passed in where a GraphenePythonError was expected",
+        )
+        return self._stack
+
+    def resolve_cause(self, _graphene_info):
+        return GraphenePythonError(self._cause) if self._cause else None
+
+    def resolve_context(self, _graphene_info):
+        return GraphenePythonError(self._context) if self._context else None
+
+    def resolve_className(self, _graphene_info):
+        check.invariant(
+            isinstance(self, GraphenePythonError),
+            f"GraphenePythonError methods called on a {type(self)} - this usually indicates that "
+            "a SerializableErrorInfo was passed in where a GraphenePythonError was expected",
+        )
+        return self._className
 
     def resolve_causes(self, _graphene_info):
         causes = []
-        current_error = self.cause
+        current_error = self._cause
         while current_error and len(causes) < 10:  # Sanity check the depth of the causes
             causes.append(GraphenePythonError(current_error))
             current_error = current_error.cause
         return causes
 
+    def resolve_errorChain(self, _graphene_info):
+        current_error = self._error_info
+        chain = []
+        while len(chain) < 10:  # Sanity check the length of the chain
+            if current_error.cause:
+                current_error = current_error.cause
+                chain.append(
+                    GrapheneErrorChainLink(
+                        error=GraphenePythonError(current_error), isExplicitLink=True
+                    )
+                )
+            elif current_error.context:
+                current_error = current_error.context
+                chain.append(
+                    GrapheneErrorChainLink(
+                        error=GraphenePythonError(current_error), isExplicitLink=False
+                    )
+                )
+            else:
+                break
+        return chain
+
 
 class GrapheneSchedulerNotDefinedError(graphene.ObjectType):
     class Meta:
