@@ -1,6 +1,7 @@
 def types():
     from .compute_logs import GrapheneComputeLogFile, GrapheneComputeLogs
     from .events import (
+        GrapheneAssetMaterializationPlannedEvent,
         GrapheneDisplayableEvent,
         GrapheneEngineEvent,
         GrapheneExecutionStepFailureEvent,
@@ -19,26 +20,31 @@ def types():
         GrapheneHookSkippedEvent,
         GrapheneLoadedInputEvent,
         GrapheneLogMessageEvent,
+        GrapheneMaterializationEvent,
         GrapheneMessageEvent,
         GrapheneMissingRunIdErrorEvent,
         GrapheneObjectStoreOperationEvent,
         GrapheneObjectStoreOperationResult,
         GrapheneObjectStoreOperationType,
+        GrapheneObservationEvent,
+        GraphenePipelineRunStepStats,
+        GrapheneResourceInitFailureEvent,
+        GrapheneResourceInitStartedEvent,
+        GrapheneResourceInitSuccessEvent,
         GrapheneRunCanceledEvent,
         GrapheneRunCancelingEvent,
         GrapheneRunDequeuedEvent,
         GrapheneRunEnqueuedEvent,
         GrapheneRunEvent,
         GrapheneRunFailureEvent,
-        GraphenePipelineRunStepStats,
-        GrapheneRunStepStats,
         GrapheneRunStartEvent,
         GrapheneRunStartingEvent,
+        GrapheneRunStepStats,
         GrapheneRunSuccessEvent,
         GrapheneStepEvent,
         GrapheneStepExpectationResultEvent,
-        GrapheneMaterializationEvent,
-        GrapheneObservationEvent,
+        GrapheneStepWorkerStartedEvent,
+        GrapheneStepWorkerStartingEvent,
         GrapheneTypeCheck,
     )
     from .log_level import GrapheneLogLevel
@@ -78,13 +84,19 @@ def types():
         GrapheneRunFailureEvent,
         GrapheneRunEvent,
         GraphenePipelineRunStepStats,
+        GrapheneResourceInitFailureEvent,
+        GrapheneResourceInitStartedEvent,
+        GrapheneResourceInitSuccessEvent,
         GrapheneRunStepStats,
         GrapheneRunStartEvent,
         GrapheneRunStartingEvent,
         GrapheneRunSuccessEvent,
         GrapheneStepEvent,
         GrapheneStepExpectationResultEvent,
+        GrapheneStepWorkerStartedEvent,
+        GrapheneStepWorkerStartingEvent,
         GrapheneMaterializationEvent,
         GrapheneObservationEvent,
         GrapheneTypeCheck,
+        GrapheneAssetMaterializationPlannedEvent,
     ]
